#include <R.h>

void ar2cov(int *n, int *k,
            double *a1, double *a2,
            double *r);
